<?php

/**
 *
 * This class is getting information about the current Open iT instalation
 *
 */
class OpeniT_Server_Info {

	private $openitServerConfig;

	public function __construct() {
		$this->openitServerConfig = new OpeniT_Server_Config();
	}


	/**
	 * Returns the current installed Open iT version number
	 * @return String Open iT Server Version Number
	 */
	public function getServerVersion() {
		$accserver = "";
		if (!strstr(PHP_OS, "WIN")){
			$accserver = $this->openitServerConfig->get('ROOT_TEMP_DIR') . '/inst/package/accserver.info';
		}else{
			$accserver = $this->openitServerConfig->get('ROOT_DIR') . '/Configuration/version';
		}

		if (file_exists($accserver)) {

			$parser = new Parser(file_get_contents($accserver), ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_WHITE_SPACE));
				
			while ($parser->hasMore()) {

				// Get line
				$line = $parser->next();

				if (strstr(PHP_OS, "WIN")){
					return $line->get(0)->toString();
				}

				// Insert key, value into array
				if ($line->get(0)->toString() == "VERSION") {
					return $line->get(1)->toString();
				}
			}
		}
	}


	/**
	 * Returning array of packages that is installed
	 * @return mixed Array of strings, packages installed
	 */
	public function getInstalledPackages() {
		$folder = $this->openitServerConfig->get('ROOT_TEMP_DIR') . '/inst/package/';
		$files = glob($folder . '*.info');

		$packages = array();
		foreach ($files as $file) {
			$file = str_replace(array($folder,'.info'), '', $file);
			$packages[] = $file;
		}

		return $packages;
	}


	/**
	 * Returns mixed array of OpeniT_Patch instanses
	 * @return mixed Array of OpeniT_Patch
	 */
	public function getInstalledPatches() {
		$folder = "";
		if (!strstr(PHP_OS, "WIN")){
			$folder = $this->openitServerConfig->get('ROOT_TEMP_DIR') . '/inst/patches/';
		}else{
			$folder = trim($this->openitServerConfig->get('ROOT_DIR')) . '/patches/';
		}

		$pacthes = array();
		$files = null;
		
		if (strstr(PHP_OS, "WIN")){
			$files = glob($folder . 'Patch*');
			foreach ($files as $file) {
				$file = substr($file,strlen($folder)+5);
				$revision = 1;
				$id = str_replace($folder, '', $file);
					
				// If we get the revision number, then we do a split
				if (strstr($id, '-')) {
					list ($id, $revision) = explode('-', $id);
				}
				//Making the info null since the patches in Windows doesn't have the information in the patches folder.
				$pacthes[$id] = new OpeniT_Patch($id, null, $revision);
			}
		}else{
			$files = glob($folder . '*');

			foreach ($files as $file) {
				if(stristr($file,"patch.log") || is_dir($file)) continue;
				$revision = 1;
				$id = str_replace($folder, '', $file);
					
				// If we get the revision number, then we do a split
				if (strstr($id, '-')) {
					list ($id, $revision) = explode('-', $id);
				}
					
				$pacthes[$id] = new OpeniT_Patch($id, file_get_contents($file), $revision);
			}
		}
		return $pacthes;
	}


	/**
	 * Returning kb of space left on the database disk
	 * @return int Space of disk free under database, in kb
	 */
	public function getAvailableDatabaseDisk() {

		// OS Checking
		// If windows
		if (strstr(PHP_OS, "WIN")){
			$output = `dir`;
			$output = explode(" ", $output);
			$count = count($output);
			$output = str_replace(",", "", $output[$count-3]);
			$fsavailable = $output / 1024;
		} else {
			//if linux
			// Find df binary
			$binDF = $this->openitServerConfig->get('BIN_DIR') . '/df';

			// Database path
			$databasePath = $this->openitServerConfig->get('ROOT_DATA_DIR');

			// Execute DF, and clean up the results
			$diskusage = shell_exec($binDF . ' -k -P -T ' . $databasePath);
			$diskusage = explode("\n", $diskusage);
			$diskusage = preg_replace('/\s\s+/', ' ', $diskusage[1]);

			//Devide the results
			list($fs, $fstype, $fstotal, $fsused, $fsavailable, $fsmount) = explode(" ", $diskusage);
		}
		// Return data

		return $fsavailable;
	}



	public function getClientLog() {
		// Find where the binary of watchlog is located
		$binWatchLog = $this->openitServerConfig->get('BIN_DIR') . '/watchlog';

		// Run watchlog with nomail and verbose mode, make sure that we add 2>&1, so we get ALL ouput
		$watchLogData = shell_exec($binWatchLog . ' --nomail --verbose 2>&1');

		// Lets pares the watchlog data
		$parser = new Parser($watchLogData, ParserSettings::create(ParserSettings::ONLY_LINES_THAT_STARTS_WITH, 'client='));

		$clients = array();

		while ($parser->hasMore()) {
				
			// Get line
			$line = $parser->next(ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_WHITE_SPACE));
				
			// Spec from the VERBOSE output, after the first WHITE_SPACE split...
			// client=192.168.210.38
			// type=FL_TY_LICPOL2
			// (daily)
			// now=0,
			// last=0
				
			// Since a parserline returns a new parserline, we can just insert new parsesettings, to split every
			// variable after the spec above..
			$host = $line->get(0, ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_EQUALS))->get(1)->toString();
			$type = $line->get(1, ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_EQUALS))->get(1)->toString();
			$freq = ucfirst(str_replace(array('(', ')'), '', $line->get(2)->toString()));
			$now = str_replace(',', '', $line->get(3, ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_EQUALS))->get(1)->toString());
			$last = $line->get(4, ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_EQUALS))->get(1)->toString();
				
			// Get client
			if (isset($clients[$host])) {
				$client =& $clients[$host];
			} else {
				$client = null;
				$client = new OpeniT_Client_Transfer_Info($host);
				$clients[$host] =& $client;
			}
				
			$client->add($type, $freq, $now, $last);
				
			unset($client);
				
		}
			
		return $clients;
	}
}

?>